pub struct SessionId {
pub uuid: String,
}Expand description
Proof Session representation
Fields
uuid: StringSession UUID
Implementations
Sourceimpl SessionId
impl SessionId
Sourcepub async fn status(&self, client: &Client) -> Result<SessionStatusRes, SdkErr>
pub async fn status(&self, client: &Client) -> Result<SessionStatusRes, SdkErr>
Fetches the current status of the Session
Sourcepub async fn logs(&self, client: &Client) -> Result<String, SdkErr>
pub async fn logs(&self, client: &Client) -> Result<String, SdkErr>
Fetches the zkvm guest logs for a session
After the Execution phase of proving is completed, you can use this method to download the logs of the zkvm guest. This is a merged log of stderr and stdout https://docs.rs/risc0-zkvm/latest/risc0_zkvm/struct.ExecutorEnvBuilder.html#method.stdout
It should contain the output of all writes to those file descriptors. But does NOT include output
from env::log