SessionStatusRes

Struct SessionStatusRes 

pub struct SessionStatusRes {
    pub status: String,
    pub receipt_url: Option<String>,
    pub error_msg: Option<String>,
    pub state: Option<String>,
    pub elapsed_time: Option<f64>,
    pub stats: Option<SessionStats>,
}
Session Status response

Fields

status: String

Current status

values: [ RUNNING | SUCCEEDED | FAILED | TIMED_OUT | ABORTED ]

receipt_url: Option<String>

Final receipt download URL

If the status == SUCCEEDED then this should be present

error_msg: Option<String>

Session Error message

If the session is not RUNNING or SUCCEEDED, this is the error raised from within bonsai, otherwise it is None.

state: Option<String>

Session Proving State

If the status is RUNNING, this is a indication of where in the proving pipeline the session currently is, otherwise it is None. Possible states in order, include:

  • Setup
  • Executor
  • ProveSegments: N/M
  • Planner
  • Recursion
  • RecursionJoin: N/M
  • Resolve
  • Finalize
  • InProgress
elapsed_time: Option<f64>

Elapsed Time

Elapsed time for a given session, in seconds

stats: Option<SessionStats>

Successful Session Stats

Stats for a given successful session. Returns:

  • Count of segments in this proof request
  • User cycles run within guest, slightly below total overhead cycles